import numpy as np

def frequencyHzToDphi(frequency):
    dphi = int(frequency/0.18626451492)
    if dphi <= 1:
        return 1
    if dphi >= 2**22:
        return 2**22-1
    else:
        return dphi

def rampHzSqToDdphi(rampHzSq):
    ddphi = int(rampHzSq/2.22044604921)
    if ddphi <= 1:
        return 1
    if ddphi >= 2**22:
        return 2**22-1
    else:
        return ddphi

def DeltaDphiAndDdphiToNsweep(DeltaDphi, Ddphi):
    return int(DeltaDphi/(Ddphi*2**-23))

def numPeriodsToNringup(numPeriods, frequencyHz):
    return int(numPeriods*100.0e6/frequencyHz)

def numPeriodsToNmeas(numPeriods, frequencyHz):
    return int(numPeriods*100.0e6/frequencyHz)

#this spits out nm and rad
def dataToAmpsPhase(data):
    amps = []
    numdata = [int.from_bytes(x[0], byteorder='little') for x in data[0]]
    cosdata = [int.from_bytes(x[0], byteorder='little') for x in data[1]]
    sindata = [int.from_bytes(x[0], byteorder='little') for x in data[2]]

    for i in range(len(cosdata)):
        if cosdata[i]&(2**63) != 0:
            cosdata[i] = cosdata[i]-2**64
    for i in range(len(sindata)):
        if sindata[i]&(2**63) != 0:
            sindata[i] = sindata[i]-2**64

    #do 2**-18 to bring sin,cos to [-1,1]
    #a 2**-6 already done by LockInAccumulator output, so do additional 2**6 to get to pm
    #now do 10**-3 to get to nm
    amps = [2**-12*10**-3*np.sqrt(2.*cosdata[i]**2+2.*sindata[i]**2)/numdata[i] for i in range(len(numdata))] #nm
    angles = [2.*np.arctan(sindata[i]/cosdata[i]) for i in range(len(numdata))]
    angles = np.angle(np.array(cosdata)+1j*np.array(sindata))
    angles_unwr = np.unwrap(angles)
    cosportion = [2**-12*10**-3*np.abs(np.sqrt(2)*cosdata[i])/numdata[i] for i in range(len(amps))]
    sinportion = [2**-12*10**-3*np.abs(np.sqrt(2)*sindata[i])/numdata[i] for i in range(len(amps))]
    return np.array(amps), [np.array(angles), np.array(angles_unwr)], np.array(cosportion), np.array(sinportion), np.array(numdata)